@@ -2,10 +2,18 @@ from __future__ import annotations
 
 import bpy
 import sys
-from subprocess import call
-from typing import Tuple
+import site
+import subprocess
+import importlib.util
+from pathlib import Path
 from zlib import decompress
 from array import array
+from typing import Tuple
+
+USER_SITE = site.getusersitepackages()
+
+if USER_SITE not in sys.path:
+    sys.path.append(USER_SITE)
 
 try:
     from PIL import Image
@@ -20,9 +28,17 @@ def support_pillow() -> bool:
 
 def install_pillow():
     '''Install Pillow and import the Image module.'''
-    args = [sys.executable, '-m', 'pip', 'install', 'Pillow']
+    args = [sys.executable, '-m', 'pip', 'install', '--user', 'Pillow']
+
+    if not subprocess.call(args=args, timeout=60):
+        path = Path(USER_SITE).joinpath('PIL', '__init__.py')
+
+        spec = importlib.util.spec_from_file_location('PIL', path)
+        module = importlib.util.module_from_spec(spec)
+
+        sys.modules[module.__name__] = module
+        spec.loader.exec_module(module)
 
-    if not call(args=args, timeout=60):
         global Image
         from PIL import Image
 
@@ -62,7 +78,7 @@ def load_file(filepath: str, max_size: tuple) -> Tuple[tuple, list]:
             data = decompress(bip.read())
 
             if support_pillow() and _should_resize((width, height), max_size):
-                image = Image.frombytes('RGBA', (width, height), data)
+                image = Image.frombytes('RGBa', (width, height), data)
                 image = _resize_image(image, max_size)
 
                 width, height = image.size
@@ -82,7 +98,12 @@ def load_file(filepath: str, max_size: tuple) -> Tuple[tuple, list]:
                 image = _resize_image(image, max_size)
 
             image = image.transpose(Image.FLIP_TOP_BOTTOM)
-            image = image.convert('RGBA')
+
+            if not image.mode.endswith(('A', 'a')):
+                image = image.convert('RGBA')
+
+            elif image.mode != 'RGBa':
+                image = image.convert('RGBa')
 
             pixels = array('i', image.tobytes())
             assert pixels.itemsize == 4, '32 bit type required for pixels'
